.. automodule:: benker.parsers
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::
   :maxdepth: 1
   :titlesonly:
   :caption: Available Parsers

   benker.parsers.base_parser
   benker.parsers.ooxml
   benker.parsers.formex
   benker.parsers.cals
